@@ -10,14 +10,13 @@
 # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations under the License.
 #
+
 from jdmn.feel.lib.type.ComparableComparator import ComparableComparator
 
 
 class StringComparator(ComparableComparator):
-    def __init__(self):
-        super().__init__()
-
-    def compareTo(self, first: str, second: str) -> int:
+    @staticmethod
+    def compareTo(first: str, second: str) -> int:
         if first == second:
             return 0
         elif first < second:
