@@ -16,7 +16,7 @@ from typing import Optional, Any
 import isodate
 from isodate import Duration
 
-from jdmn.feel.lib.Types import DATE, TIME, DATE_TIME, INT, DATE_TIME_UNION, DURATION, LONG
+from jdmn.feel.lib.Types import DATE, TIME, DATE_TIME, INTEGER, DATE_TIME_UNION, DURATION
 from jdmn.feel.lib.type.BaseType import BaseType
 from jdmn.feel.lib.type.bool.DefaultBooleanType import DefaultBooleanType
 
@@ -38,10 +38,12 @@ class DefaultCalendarType(BaseType):
     def isDateTime(obj: Any) -> bool:
         return isinstance(obj, datetime)
 
-    def isDuration(self, value: Any):
-        return isinstance(value, Duration) or isinstance(value, timedelta)
+    @staticmethod
+    def isDuration(value: Any):
+        return isinstance(value, (Duration, timedelta))
 
-    def isYearsAndMonthsDuration(self, value):
+    @staticmethod
+    def isYearsAndMonthsDuration(value):
         if isinstance(value, Duration):
             return not (value.years == 0 and value.months == 0) and value.tdelta.total_seconds() == 0.0
         elif isinstance(value, timedelta):
@@ -49,7 +51,8 @@ class DefaultCalendarType(BaseType):
         else:
             return False
 
-    def isDaysAndTimeDuration(self, value: Any):
+    @staticmethod
+    def isDaysAndTimeDuration(value: Any):
         if isinstance(value, Duration):
             return value.years == 0 and value.months == 0 and value.tdelta.total_seconds() != 0.0
         elif isinstance(value, timedelta):
@@ -79,7 +82,7 @@ class DefaultCalendarType(BaseType):
                first.day == second.day and first.hour == second.hour and first.minute == second.minute and first.second == second.second and \
                self.sameTzInfo(first.tzinfo, second.tzinfo)
 
-    def value(self, calendar: DATE_TIME_UNION) -> INT:
+    def value(self, calendar: DATE_TIME_UNION) -> INTEGER:
         if self.isDate(calendar):
             return self.dateValue(calendar)
         elif self.isTime(calendar):
@@ -89,13 +92,13 @@ class DefaultCalendarType(BaseType):
         else:
             return None
 
-    def dateValue(self, date_: DATE) -> INT:
+    def dateValue(self, date_: DATE) -> INTEGER:
         if date_ is None:
             return None
 
         return self.dateTimeValue(self.dateToDateTime(date_))
 
-    def timeValue(self, time_: TIME) -> INT:
+    def timeValue(self, time_: TIME) -> INTEGER:
         if time_ is None:
             return None
 
@@ -104,7 +107,8 @@ class DefaultCalendarType(BaseType):
             value -= time_.tzinfo.utcoffset(self.EP).seconds
         return value
 
-    def dateTimeValue(self, datetime_: DATE_TIME) -> Optional[int]:
+    @staticmethod
+    def dateTimeValue(datetime_: DATE_TIME) -> Optional[int]:
         if datetime_ is None:
             return None
 
@@ -115,10 +119,11 @@ class DefaultCalendarType(BaseType):
         timestamp = datetime_.timestamp()
         return int(timestamp)
 
-    def canNotSubtract(self, first: DATE_TIME, second: DATE_TIME) -> bool:
+    @staticmethod
+    def canNotSubtract(first: DATE_TIME, second: DATE_TIME) -> bool:
         return first.tzinfo is None and second.tzinfo is not None or first.tzinfo is not None and second.tzinfo is None
 
-    def durationValue(self, duration: Duration) -> LONG:
+    def durationValue(self, duration: Duration) -> INTEGER:
         if duration is None:
             return None
 
@@ -130,7 +135,7 @@ class DefaultCalendarType(BaseType):
             return int((self.EP + duration).timestamp())
 
     @staticmethod
-    def monthsValue(duration: DURATION) -> LONG:
+    def monthsValue(duration: DURATION) -> INTEGER:
         if duration is None:
             return None
 
@@ -140,13 +145,14 @@ class DefaultCalendarType(BaseType):
         return totalMonths
 
     @staticmethod
-    def secondsValue(duration: DURATION) -> LONG:
+    def secondsValue(duration: DURATION) -> INTEGER:
         if duration is None:
             return None
 
         return int(duration.total_seconds())
 
-    def sameTzInfo(self, tz1: isodate.tzinfo, tz2: isodate.tzinfo) -> bool:
+    @staticmethod
+    def sameTzInfo(tz1: isodate.tzinfo, tz2: isodate.tzinfo) -> bool:
         if tz1 is tz2 or tz1 == tz2:
             return True
         else:
